OpusFlutterLinux class
An implementation of OpusFlutterPlatform for Linux.
Loads a bundled libopus shared library from Flutter assets. If the bundled
binary cannot be loaded (e.g. missing asset or unsupported architecture),
falls back to the system-installed libopus.so.0.
- Inheritance
-
- Object
- PlatformInterface
- OpusFlutterLinux
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
load(
) → Future< Object> - Opens the opus shared library.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void -
Registers this class as the default instance of
OpusFlutterPlatform.